@@ -84,8 +84,8 @@ class AnalysisForm(forms.Form):
     nd = forms.BooleanField(initial=True,required=False,label='Neighbourhood density')
     phonotactic = forms.BooleanField(initial=True,required=False,label='Phonotactic probability')
     lexical_scale = forms.CharField(label = 'Corpora to use for lexical statistics')
-    lexical_scale.widget = forms.CheckboxSelectMultiple(choices=LEX_SCALE_CHOICES)
-    additional_phono_stats = forms.BooleanField(initial=True,required=False,label='Additional phonological statistics')
+    lexical_scale.widget = forms.CheckboxSelectMultiple(required=False,choices=LEX_SCALE_CHOICES)
+    additional_phono_stats = forms.BooleanField(initial=False,required=False,label='Additional phonological statistics')
     gender = forms.BooleanField(initial=True,required=False,label='Gender')
     age = forms.BooleanField(initial=True,required=False,label='Age')
     globalSpeakingRate = forms.BooleanField(initial=True,required=False,label='Global speaking rate')
@@ -95,9 +95,9 @@ class AnalysisForm(forms.Form):
     prev_sem_pred = forms.BooleanField(initial=True,required=False,label='Previous semantic predictability')
     foll_sem_pred = forms.BooleanField(initial=True,required=False,label='Following semantic predictability')
     pause_dist = forms.BooleanField(initial=True,required=False,label='Distance to pauses')
-    sem_pred_window = forms.CharField(label='Semantic predictability window')
+    sem_pred_window = forms.CharField(required=False,label='Semantic predictability window')
     sem_pred_window.widget = forms.CheckboxSelectMultiple(choices=SEM_PRED_WINDOW)
-    sem_pred_style = forms.CharField(label='Semantic predictability style')
+    sem_pred_style = forms.CharField(required=False,label='Semantic predictability style')
     sem_pred_style.widget = forms.CheckboxSelectMultiple(choices=SEM_PRED_STYLE)
 
     #force_fetch = forms.CharField(label='Force fetch')
@@ -166,7 +166,7 @@ class AnalysisForm(forms.Form):
             wanted_fields.extend(['PhonoStatsBlickPhono'])
             wanted_fields.extend(['PhonoStatsSPhoneProb','PhonoStatsBiPhoneProb'])
 
-        if 'VB' in form['phonotactic']:
+        if form['phonotactic']:
             if 'C' in form['lexical_scale']:
                 wanted_fields.extend(['CelexSPhoneProb','CelexBiPhoneProb'])
             if 'W' in form['lexical_scale']:
